import lowRange from './lowRange';
import highRange from './highRange';
/**
 * Gets the proper range for the page number according to the number of pages to display
 * @param {object} params - parameters pagination
 * @param {number} params.page - Original page number
 * @param {number} params.totalPages - Total number of pages
 * @param {number} params.showPages - Number of pages to display in the range of pages displayed
 * @return {number[]} range of page numbers
 */

var range = function range(_ref) {
  var page = _ref.page,
      totalPagesParam = _ref.totalPages,
      showEdges = _ref.showEdges,
      showPages = _ref.showPages;
  var totalPages = showEdges ? totalPagesParam - 1 : totalPagesParam;

  var _lowRange = lowRange({
    page: page,
    showEdges: showEdges,
    showPages: showPages,
    totalPages: totalPages
  });

  var _highRangeFixer = showPages > totalPages ? totalPages - 1 : showPages;

  var _highRange = showEdges ? _lowRange + _highRangeFixer : highRange({
    page: page,
    totalPages: totalPages,
    showPages: showPages
  });

  var rangeNumItems = _highRange === totalPages ? totalPages - _lowRange : showPages;
  return rangeNumItems > 0 ? [].concat(Array.from(new Array(rangeNumItems), function (_, i) {
    return _lowRange + i + 1;
  })) : [];
};

export default range;