import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import AtomButton, { atomButtonSizes } from '@s-ui/react-atom-button';
import * as pagination from './helpers/pagination';
import { isValidPage, isValidTotalPages, isValidShowPages } from './customPropTypes';
var BASE_CLASS = 'sui-MoleculePagination';
var CLASS_PREV_BUTTON_ICON = 'sui-MoleculePagination-prevButtonIcon';
var CLASS_NEXT_BUTTON_ICON = 'sui-MoleculePagination-nextButtonIcon';
var PAGE_NUMBER_HOLDER = '%{pageNumber}';
var DIVIDER = '···';

var PageButton = function PageButton(_ref) {
  var onSelectPage = _ref.onSelectPage,
      page = _ref.page,
      design = _ref.design,
      color = _ref.color,
      props = _objectWithoutPropertiesLoose(_ref, ["onSelectPage", "page", "design", "color"]);

  var _onSelectPage = function _onSelectPage(e) {
    onSelectPage(e, {
      page: page
    });
  };

  return /*#__PURE__*/_jsx("li", {
    className: BASE_CLASS + "-item",
    children: /*#__PURE__*/_jsx(AtomButton, _extends({
      onClick: _onSelectPage,
      design: design,
      color: color
    }, props))
  });
};

var defaultCreateUrl = function defaultCreateUrl(_ref2) {
  var pageNumber = _ref2.pageNumber,
      urlPattern = _ref2.urlPattern;
  return urlPattern.replace(PAGE_NUMBER_HOLDER, pageNumber);
};

var noop = function noop() {};

var MoleculePagination = function MoleculePagination(_ref3) {
  var _ref3$onSelectNext = _ref3.onSelectNext,
      onSelectNext = _ref3$onSelectNext === void 0 ? noop : _ref3$onSelectNext,
      _ref3$onSelectPage = _ref3.onSelectPage,
      onSelectPage = _ref3$onSelectPage === void 0 ? noop : _ref3$onSelectPage,
      _ref3$onSelectPrev = _ref3.onSelectPrev,
      onSelectPrev = _ref3$onSelectPrev === void 0 ? noop : _ref3$onSelectPrev,
      _ref3$page = _ref3.page,
      page = _ref3$page === void 0 ? 1 : _ref3$page,
      totalPages = _ref3.totalPages,
      _ref3$showPages = _ref3.showPages,
      showPages = _ref3$showPages === void 0 ? 10 : _ref3$showPages,
      _ref3$prevButtonText = _ref3.prevButtonText,
      prevButtonText = _ref3$prevButtonText === void 0 ? 'Previous' : _ref3$prevButtonText,
      PrevButtonIcon = _ref3.prevButtonIcon,
      _ref3$nextButtonText = _ref3.nextButtonText,
      nextButtonText = _ref3$nextButtonText === void 0 ? 'Next' : _ref3$nextButtonText,
      NextButtonIcon = _ref3.nextButtonIcon,
      _ref3$compressed = _ref3.compressed,
      compressed = _ref3$compressed === void 0 ? false : _ref3$compressed,
      hideDisabled = _ref3.hideDisabled,
      _ref3$selectedPageBut = _ref3.selectedPageButtonDesign,
      selectedPageButtonDesign = _ref3$selectedPageBut === void 0 ? 'solid' : _ref3$selectedPageBut,
      showEdges = _ref3.showEdges,
      _ref3$nonSelectedPage = _ref3.nonSelectedPageButtonDesign,
      nonSelectedPageButtonDesign = _ref3$nonSelectedPage === void 0 ? 'flat' : _ref3$nonSelectedPage,
      _ref3$prevButtonDesig = _ref3.prevButtonDesign,
      prevButtonDesign = _ref3$prevButtonDesig === void 0 ? 'flat' : _ref3$prevButtonDesig,
      _ref3$nextButtonDesig = _ref3.nextButtonDesign,
      nextButtonDesign = _ref3$nextButtonDesig === void 0 ? 'flat' : _ref3$nextButtonDesig,
      _ref3$selectedPageBut2 = _ref3.selectedPageButtonColor,
      selectedPageButtonColor = _ref3$selectedPageBut2 === void 0 ? 'primary' : _ref3$selectedPageBut2,
      size = _ref3.size,
      _ref3$nonSelectedPage2 = _ref3.nonSelectedPageButtonColor,
      nonSelectedPageButtonColor = _ref3$nonSelectedPage2 === void 0 ? 'primary' : _ref3$nonSelectedPage2,
      _ref3$prevButtonColor = _ref3.prevButtonColor,
      prevButtonColor = _ref3$prevButtonColor === void 0 ? 'primary' : _ref3$prevButtonColor,
      _ref3$nextButtonColor = _ref3.nextButtonColor,
      nextButtonColor = _ref3$nextButtonColor === void 0 ? 'primary' : _ref3$nextButtonColor,
      linkFactory = _ref3.linkFactory,
      _ref3$createUrl = _ref3.createUrl,
      createUrl = _ref3$createUrl === void 0 ? defaultCreateUrl : _ref3$createUrl,
      _ref3$urlPattern = _ref3.urlPattern,
      urlPattern = _ref3$urlPattern === void 0 ? '#' : _ref3$urlPattern,
      _ref3$renderLinks = _ref3.renderLinks,
      renderLinks = _ref3$renderLinks === void 0 ? false : _ref3$renderLinks;
  var paramsPagination = {
    page: page,
    totalPages: totalPages,
    showPages: showPages,
    showEdges: showEdges
  };

  var handleClickNext = function handleClickNext(e) {
    var page = pagination.nextPage(paramsPagination);
    onSelectNext(e, {
      page: page
    });
  };

  var handleClickPrev = function handleClickPrev(e) {
    var page = pagination.prevPage(paramsPagination);
    onSelectPrev(e, {
      page: page
    });
  };

  var range = pagination.range(paramsPagination);
  var nextPage = pagination.nextPage(paramsPagination);
  var prevPage = pagination.prevPage(paramsPagination);
  var isHidePrev = hideDisabled && !prevPage;
  var isHideNext = hideDisabled && !nextPage;

  var linkProps = function linkProps(pageNumber) {
    return renderLinks && _extends({
      link: true,
      href: createUrl({
        pageNumber: pageNumber,
        urlPattern: urlPattern
      })
    }, linkFactory && {
      linkFactory: linkFactory
    });
  };

  return /*#__PURE__*/_jsxs("ul", {
    className: BASE_CLASS,
    children: [!isHidePrev && /*#__PURE__*/_jsx("li", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsxs(AtomButton, _extends({
        onClick: handleClickPrev,
        design: prevButtonDesign,
        color: prevButtonColor,
        disabled: !prevPage,
        size: size
      }, linkProps(prevPage), {
        children: [PrevButtonIcon && /*#__PURE__*/_jsx("span", {
          className: CLASS_PREV_BUTTON_ICON,
          children: /*#__PURE__*/_jsx(PrevButtonIcon, {})
        }), prevButtonText]
      }))
    }), compressed ? /*#__PURE__*/_jsx(PageButton, _extends({
      page: page,
      design: selectedPageButtonDesign,
      color: selectedPageButtonColor,
      onSelectPage: onSelectPage,
      size: size
    }, linkProps(page), {
      children: page
    })) : /*#__PURE__*/_jsxs(_Fragment, {
      children: [showEdges && /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(PageButton, _extends({
          page: 1,
          design: page === 1 ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
          color: page === 1 ? selectedPageButtonColor : nonSelectedPageButtonColor,
          onSelectPage: onSelectPage,
          size: size
        }, linkProps(1), {
          children: 1
        }), 1), page > showPages && showPages + 2 < totalPages - 1 && /*#__PURE__*/_jsx("li", {
          className: BASE_CLASS + "-divider",
          children: DIVIDER
        })]
      }), range.map(function (pageRange) {
        return /*#__PURE__*/_jsx(PageButton, _extends({
          page: pageRange,
          design: pageRange === page ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
          color: pageRange === page ? selectedPageButtonColor : nonSelectedPageButtonColor,
          onSelectPage: onSelectPage,
          size: size
        }, linkProps(pageRange), {
          children: pageRange
        }), pageRange);
      }), showEdges && totalPages > 1 && /*#__PURE__*/_jsxs(_Fragment, {
        children: [range[range.length - 1] < totalPages - 1 && /*#__PURE__*/_jsx("li", {
          className: BASE_CLASS + "-divider",
          children: DIVIDER
        }), /*#__PURE__*/_jsx(PageButton, _extends({
          page: totalPages,
          design: page === totalPages ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
          color: page === totalPages ? selectedPageButtonColor : nonSelectedPageButtonColor,
          onSelectPage: onSelectPage,
          size: size
        }, linkProps(totalPages), {
          children: totalPages
        }), totalPages)]
      })]
    }), !isHideNext && /*#__PURE__*/_jsx("li", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsxs(AtomButton, _extends({
        onClick: handleClickNext,
        design: nextButtonDesign,
        color: nextButtonColor,
        disabled: !nextPage,
        size: size
      }, linkProps(nextPage), {
        children: [nextButtonText, NextButtonIcon && /*#__PURE__*/_jsx("span", {
          className: CLASS_NEXT_BUTTON_ICON,
          children: /*#__PURE__*/_jsx(NextButtonIcon, {})
        })]
      }))
    })]
  });
};

MoleculePagination.displayName = 'MoleculePagination';
export default MoleculePagination;